CheckKey

Enum CheckKey 

pub enum CheckKey {
    Store(StoreCheckKey),
    PublicName {
        object: Object,
        relation: RelationName,
        user: User,
    },
    Public {
        object: Object,
        relation: Relation,
        user: User,
    },
}
Immutable key for recursion tracking.

Variants



Store(StoreCheckKey)

Store-native identifier key for relationships already interned in the compact snapshot.



PublicName

Validated public object/relation-name key used when a segment-native compact key is not available, such as checkpoint-plus-delta views.

Fields

object: Object

Object being checked.

relation: RelationName

Validated relation or permission name being checked.

user: User

Subject being checked.



Public

Owned public-model fallback when at least one identifier is absent from the snapshot.

Fields

object: Object

Object being checked.

relation: Relation

Relation or permission being checked.

user: User

Subject being checked.