pub enum ExpandedUserset {
User(String),
Userset(Object, Relation),
Union(Vec<ExpandedUserset>),
Intersection(Vec<ExpandedUserset>),
Exclusion {
base: Box<ExpandedUserset>,
exclude: Box<ExpandedUserset>,
},
}Expand description
Represents the result of an expand operation, detailing the effective userset.
Variants
User(String)
A specific user who has the permission.
Userset(Object, Relation)
A reference to another userset that contributes to the permission.
Union(Vec<ExpandedUserset>)
The union of multiple expanded usersets.
Intersection(Vec<ExpandedUserset>)
The intersection of multiple expanded usersets.
Exclusion
The exclusion of one expanded userset from another.
Fields

base: Box<ExpandedUserset>Base expanded userset.

exclude: Box<ExpandedUserset>Expanded userset to subtract from the base.