pub enum StoreError {
RelationshipAlreadyExists {
relationship: Box<Relationship>,
},
RelationshipNotFound {
relationship: Box<Relationship>,
},
DuplicateMutation {
relationship: Box<Relationship>,
},
PreconditionFailed {
precondition: Box<Precondition>,
},
MutationBatchTooLarge {
limit: usize,
actual: usize,
},
PreconditionBatchTooLarge {
limit: usize,
actual: usize,
},
CapacityExceeded {
component: &'static str,
},
InternalInvariant {
reason: &'static str,
},
DomainMaterialization {
message: String,
},
}Expand description
Errors produced by the indexed relationship store.
Variants
RelationshipAlreadyExists
A create mutation attempted to insert an existing relationship.
Fields

relationship: Box<Relationship>Duplicate relationship.
RelationshipNotFound
A delete mutation targeted a missing relationship.
Fields

relationship: Box<Relationship>Missing relationship.
DuplicateMutation
A mutation batch contains conflicting mutations for the same relationship.
Fields

relationship: Box<Relationship>Duplicated relationship key.
PreconditionFailed
A precondition failed.
Fields

precondition: Box<Precondition>Failed precondition.
MutationBatchTooLarge
A mutation batch exceeded the configured in-memory store cap.
PreconditionBatchTooLarge
A precondition batch exceeded the configured in-memory store cap.
CapacityExceeded
A compact store id space was exhausted.
InternalInvariant
A compact store invariant was violated.
DomainMaterialization
Validated compact data failed to materialize back to a domain value.