SchemaError

Enum SchemaError 

pub enum SchemaError {
    DuplicateNamespace {
        namespace: String,
    },
    DuplicateRelation {
        namespace: String,
        relation: String,
    },
    NamespaceNotFound {
        namespace: String,
    },
    RelationNotFound {
        namespace: String,
        relation: String,
    },
    MissingRelationReference {
        namespace: String,
        owner: String,
        relation: &'static str,
        missing: String,
    },
    MissingTupleToUsersetTarget {
        namespace: String,
        owner: String,
        missing: String,
    },
    EmptyExpression {
        namespace: String,
        owner: String,
        operator: &'static str,
        min_operands: usize,
    },
}
Errors produced while compiling or validating schemas.

Variants



DuplicateNamespace

The schema has two definitions with the same object type.

Fields

namespace: String

Duplicate namespace name.



DuplicateRelation

A namespace has two relations or permissions with the same name.

Fields

namespace: String

Namespace containing the duplicate.

relation: String

Duplicate relation name.



NamespaceNotFound

A namespace was requested but is not present in the schema.

Fields

namespace: String

Missing namespace name.



RelationNotFound

A relation was requested but is not present in the namespace.

Fields

namespace: String

Namespace searched.

relation: String

Missing relation name.



MissingRelationReference

A schema expression references a relation that does not exist.

Fields

namespace: String

Namespace containing the owner relation.

owner: String

Relation that owns the invalid expression.

relation: &'static str

Invalid expression edge.

missing: String

Missing relation name.



MissingTupleToUsersetTarget

A tuple-to-userset target relation cannot be resolved from the known schema.

Fields

namespace: String

Namespace containing the owner relation.

owner: String

Relation that owns the invalid expression.

missing: String

Missing target relation name.



EmptyExpression

A set operation does not contain enough operands.

Fields

namespace: String

Namespace containing the owner relation.

owner: String

Relation that owns the invalid expression.

operator: &'static str

Operator name.

min_operands: usize

Minimum operand count.