pub struct CompiledSchema { /* private fields */ }Expand description
Immutable compiled schema.
Implementations
Sourceimpl CompiledSchema
impl CompiledSchema
Sourcepub fn from_definitions(
definitions: impl IntoIterator<Item = NamespaceDefinition>,
) -> Result<Self, SchemaError>
pub fn from_definitions( definitions: impl IntoIterator<Item = NamespaceDefinition>, ) -> Result<Self, SchemaError>
Creates and validates a compiled schema from typed namespace definitions.
Errors
Returns SchemaError when definitions are duplicated or expression references cannot be
resolved.
Sourcepub fn definitions(&self) -> &[NamespaceDefinition]
pub fn definitions(&self) -> &[NamespaceDefinition]
Returns all namespace definitions in source order.
Sourcepub fn resolver(&self) -> &SchemaResolver
pub fn resolver(&self) -> &SchemaResolver
Returns the schema resolver.
Sourcepub fn validate_relationship(
&self,
relationship: &Relationship,
) -> Result<(), SchemaError>
pub fn validate_relationship( &self, relationship: &Relationship, ) -> Result<(), SchemaError>
Validates that a relationship references a known resource namespace and relation.
Errors
Returns SchemaError::RelationNotFound or SchemaError::NamespaceNotFound when the
relationship resource does not match this schema.