#[non_exhaustive]pub struct StoreViewDeltaStats {
pub checkpoint_rows: usize,
pub delta_segments: usize,
pub delta_inserted_rows: usize,
pub delta_deleted_rows: usize,
pub delta_mutations: usize,
pub tombstone_ratio_bps: u16,
}Expand description
Benchmark-only delta shape for one published relationship-store view.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.checkpoint_rows: usizeNumber of rows in the checkpoint store.
delta_segments: usizeNumber of delta overlays retained by the view.
delta_inserted_rows: usizeNumber of inserted rows in the current delta overlay.
delta_deleted_rows: usizeNumber of checkpoint rows masked by delta tombstones.
delta_mutations: usizeNumber of mutations represented by the current delta overlay.
tombstone_ratio_bps: u16Deleted-row ratio in basis points over checkpoint plus inserted rows.